==> jboss-wfk-2.1.0-errai-tech-preview-src.zip: jboss-wfk-2.1.0/src/errai-2.1.0.Final-redhat-1/errai-jaxrs/errai-jaxrs-client/src/test/java/org/jboss/errai/enterprise/jaxrs/client/TestModule.java <==
/*
 * Copyright 2011 JBoss, by Red Hat, Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.errai.enterprise.jaxrs.client;

import javax.annotation.PostConstruct;
import javax.inject.Inject;

import org.jboss.errai.enterprise.jaxrs.client.shared.CustomTypeTestService;
import org.jboss.errai.enterprise.jaxrs.client.shared.ErrorHandlingTestService;
import org.jboss.errai.enterprise.jaxrs.client.shared.PlainMethodTestService;
import org.jboss.errai.ioc.client.api.Caller;
import org.jboss.errai.ioc.client.api.EntryPoint;

/**
 * EntryPoint used for caller injection.
 * 
 * @author Christian Sadilek <csadilek@redhat.com>
 */
@EntryPoint
public class TestModule {

  private static TestModule instance;
  
  @Inject
  private Caller<PlainMethodTestService> plainMethodTestService;

  @Inject
  private Caller<CustomTypeTestService> customTypeTestService;
  
  @Inject
  private Caller<ErrorHandlingTestService> errorHandlingTestService;

  @PostConstruct
  public void doPostConstruct() {
    instance = this;
  }
  
  public static TestModule getInstance() {
    return instance;
  }
  
  public Caller<PlainMethodTestService> getPlainMethodTestService() {
    return plainMethodTestService;
  }
  
  public Caller<CustomTypeTestService> getCustomTypeTestService() {
    return customTypeTestService;
  }
  
  public Caller<ErrorHandlingTestService> getErrorHandlingTestService() {
    return errorHandlingTestService;
  }
}

==> jboss-wfk-2.3.0-errai-tech-preview-src.zip: jboss-wfk-2.3.0/src/errai-2.3.2.Final-redhat-1/errai-jaxrs/errai-jaxrs-client/src/test/java/org/jboss/errai/enterprise/jaxrs/client/TestModule.java <==
/*
 * Copyright 2011 JBoss, by Red Hat, Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.errai.enterprise.jaxrs.client;

import javax.annotation.PostConstruct;
import javax.inject.Inject;

import org.jboss.errai.enterprise.jaxrs.client.shared.CustomTypeTestService;
import org.jboss.errai.enterprise.jaxrs.client.shared.ErrorHandlingTestService;
import org.jboss.errai.enterprise.jaxrs.client.shared.PlainMethodTestService;
import org.jboss.errai.ioc.client.api.Caller;
import org.jboss.errai.ioc.client.api.EntryPoint;

/**
 * EntryPoint to test caller injection.
 * 
 * @author Christian Sadilek <csadilek@redhat.com>
 */
@EntryPoint
public class TestModule {

  private static TestModule instance;
  
  @Inject
  private Caller<PlainMethodTestService> plainMethodTestService;

  @Inject
  private Caller<CustomTypeTestService> customTypeTestService;
  
  @Inject
  private Caller<ErrorHandlingTestService> errorHandlingTestService;

  @PostConstruct
  public void doPostConstruct() {
    instance = this;
  }
  
  public static TestModule getInstance() {
    return instance;
  }
  
  public Caller<PlainMethodTestService> getPlainMethodTestService() {
    return plainMethodTestService;
  }
  
  public Caller<CustomTypeTestService> getCustomTypeTestService() {
    return customTypeTestService;
  }
  
  public Caller<ErrorHandlingTestService> getErrorHandlingTestService() {
    return errorHandlingTestService;
  }
}
